<script setup>
import { useI18n } from 'vue-i18n';
import { router } from '@inertiajs/vue3';
import { ref, onMounted, onUnmounted, watch, onUpdated } from 'vue';

import Modal from '@/Jetstream/Modal.vue';
import AppLayout from '@/Layouts/AppLayout.vue';

const { t } = useI18n({});

const year = ref(null);
const show = ref(false);
const yearData = ref(null);
const props = defineProps(['data', 'html', 'current_year', 'prev_year_link', 'next_year_link']);

year.value = props.current_year;
onMounted(async () => {
  document.querySelectorAll('.amount').forEach(item => {
    item.addEventListener('click', event => {
      yearData.value = props.data[event.target.dataset.month] || {};
      if (yearData.value.month) {
        show.value = true;
      }
    });
  });
});

// onUpdated(() => {
//   month.value = props.current_month;
// });

// watch(month, month => {
//   console.log(month);
//   let [sel_year, sel_month] = month.split('-');
//   router.visit(route('reports.monthly_sales', { year: sel_year, month: sel_month }), {
//     only: ['data', 'html'],
//     preserveScroll: true,
//     onSuccess: p => {
//       console.log(p.props.current_month);
//       month.value = p.props.value.current_month;
//     },
//   });
//   //   router.visit(route('reports.monthly_sales', { year: sel_year, month: sel_month }), {
//   //     onSuccess: p => {
//   //       console.log(p);
//   //       //   month.value = p.props.current_month;
//   //     },
//   //   });
// });

// onUnmounted(() => {
//   document.querySelector('.mpnthly-sales').replaceWith(document.querySelector('.mpnthly-sales').cloneNode(true));
// });

const yearChanged = e => {
  router.visit(route('reports.monthly_sales', { year: e.target.value }), { preserveScroll: true });
};
</script>

<template>
  <AppLayout :title="t('Monthly Invoices')">
    <div class="py-8">
      <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
        <div class="bg-white dark:bg-gray-900 shadow sm:rounded-lg">
          <div class="sm:rounded-lg">
            <div class="p-6 sm:rounded-t-lg border-b border-gray-200 dark:border-gray-700 block md:flex md:items-center md:justify-between">
              <div>
                <div class="text-2xl">
                  {{ t('Monthly Invoices') }}
                </div>
                <div class="mt-1 text-gray-500 dark:text-gray-400">{{ t('Please review the result below') }}</div>
              </div>
            </div>

            <div class="monthly-sales bg-white dark:bg-gray-900 border-b dark:border-gray-700 sm:rounded-b-lg">
              <div class="flex items-center justify-between px-4 mt-6">
                <Link
                  :href="prev_year_link"
                  class="p-1.5 hover:bg-gray-200 dark:hover:bg-gray-700 border-2 dark:border-gray-700 rounded-md"
                >
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    fill="none"
                    viewBox="0 0 24 24"
                    stroke-width="1.5"
                    stroke="currentColor"
                    class="w-5 h-5"
                  >
                    <path stroke-linecap="round" stroke-linejoin="round" d="M15.75 19.5L8.25 12l7.5-7.5" />
                  </svg>
                </Link>
                <!-- v-model="month" -->
                <input
                  step="1"
                  id="year"
                  min="1900"
                  max="2099"
                  name="year"
                  type="number"
                  :value="current_year"
                  @change="yearChanged"
                  class="appearance-none border-0 w-auto min-w-0 max-w-full bg-white dark:bg-gray-900 text-gray-700 dark:text-gray-300 text-lg font-bold py-1 px-2 focus:outline-none focus:ring-1 focus:ring-inset focus:ring-blue-500"
                />
                <!-- <div class="flex items-center justify-center text-xl font-bold uppercase">{{ current_year }}</div> -->
                <Link
                  :href="next_year_link"
                  class="p-1.5 hover:bg-gray-200 dark:hover:bg-gray-700 border-2 dark:border-gray-700 rounded-md"
                >
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    fill="none"
                    viewBox="0 0 24 24"
                    stroke-width="1.5"
                    stroke="currentColor"
                    class="w-5 h-5"
                  >
                    <path stroke-linecap="round" stroke-linejoin="round" d="M8.25 4.5l7.5 7.5-7.5 7.5" />
                  </svg>
                </Link>
              </div>
              <div v-html="html"></div>
            </div>
          </div>
        </div>
      </div>
    </div>
    <Modal :show="show" :closeable="true" @close="show = false" maxWidth="sm">
      <div class="px-6 pt-3 pb-6 print:px-0 bg-gray-100 dark:bg-gray-800">
        <div class="text-lg font-bold capitalize">
          {{ $month(new Date(yearData.year, yearData.month - 1)) }}
        </div>
        <!-- <p>{{ t('Please review the year data below') }}</p> -->
        <div>
          <div class="mt-4">
            <table class="w-full divide-y dark:divide-gray-700">
              <tr>
                <td>{{ t('Total') }}</td>
                <td class="text-right">{{ $number(yearData.total) }}</td>
              </tr>
              <tr>
                <td>{{ t('Tax') }}</td>
                <td class="text-right">{{ $number(yearData.total_tax_amount) }}</td>
              </tr>
              <tr class="font-bold">
                <td>{{ t('Grand Total') }}</td>
                <td class="text-right">{{ $number(yearData.grand_total) }}</td>
              </tr>
              <tr>
                <td>{{ t('Received') }}</td>
                <td class="text-right">{{ $number(yearData.paid) }}</td>
              </tr>
              <tr class="font-bold">
                <td>{{ t('Balance') }}</td>
                <td class="text-right">{{ $number(yearData.grand_total - yearData.paid) }}</td>
              </tr>
              <!-- <tr>
                <td></td>
                <td></td>
              </tr>
              <tr class="font-bold text-lg">
                <td>{{ t('Total Payment') }}</td>
                <td class="text-right">{{ $number(yearData.payment) }}</td>
              </tr> -->
            </table>
          </div>
        </div>
      </div>
    </Modal>
  </AppLayout>
</template>

<style>
.calendar {
  @apply flex flex-col relative px-4 pt-2 pb-5 w-full bg-white dark:bg-gray-900 rounded-b-lg;
}

/* .month-year {
  @apply flex items-center justify-center text-xl font-bold uppercase mb-3;
}

.year {
  @apply ml-3;
} */

.months {
  @apply grid grid-cols-6 border dark:border-gray-700 rounded-md overflow-hidden;
}
.month {
  @apply capitalize p-2 border dark:border-gray-700;
}
.month.month-1 {
  @apply rounded-tl-md;
}
.month.month-6 {
  @apply rounded-tr-md;
}
.month.month-7 {
  @apply rounded-bl-md;
}
.month.month-12 {
  @apply rounded-br-md;
}

.amount {
  @apply mt-1 px-2 py-1 text-right rounded-md bg-gray-100 dark:bg-gray-800 cursor-default;
}
.amount.data {
  @apply cursor-pointer;
}
</style>
